﻿namespace U2UConsult.WinRTBehaviors.Sample
{
    using Windows.UI.Xaml;
    using Windows.UI.Xaml.Controls;
    using WinRtBehaviors;

    /// <summary>
    /// Behavior that selects all text in a textBox when it gets the focus.
    /// </summary>
    /// <remarks>
    /// Based on http://eladm.wordpress.com/2009/04/02/attached-behavior/
    /// </remarks>
    public class SelectAllOnFocusBehavior : Behavior<TextBox>
    {
        #region Attached Dependency Properties

        /// <summary>
        /// The SelectAllOnFocus attached dependency property registration.
        /// </summary>
        public static readonly DependencyProperty SelectAllOnFocusProperty =
            DependencyProperty.RegisterAttached
            (
                "SelectAllOnFocus",
                typeof(bool),
                typeof(SelectAllOnFocusBehavior),
                new PropertyMetadata(false)
            );

        /// <summary>
        /// Wrapper for property getter.
        /// </summary>
        public static bool GetSelectAllOnFocus(DependencyObject obj)
        {
            return (bool)obj.GetValue(SelectAllOnFocusProperty);
        }

        /// <summary>
        /// Wrapper for property setter.
        /// </summary>
        public static void SetSelectAllOnFocus(DependencyObject obj, bool value)
        {
            obj.SetValue(SelectAllOnFocusProperty, value);
        }

        #endregion

        #region Attached and Detaching

        /// <summary>
        /// Called when behavior is attached.
        /// </summary>
        protected override void OnAttached()
        {
            base.OnAttached();
            
            if (AssociatedObject != null)
            {
                if (GetSelectAllOnFocus(this))
                {
                    AssociatedObject.GotFocus += AssociatedObject_GotFocus;
                }
            }
        }

        /// <summary>
        /// Called when behavior is detaching.
        /// </summary>
        protected override void OnDetaching()
        {
            if (AssociatedObject != null)
            {
                if (GetSelectAllOnFocus(this))
                {
                    AssociatedObject.GotFocus -= AssociatedObject_GotFocus;
                }
            }

            base.OnDetaching();
        }

        #endregion

        #region Core Logic

        /// <summary>
        /// Handles the GotFocus event of the AssociatedObject - a TextBox.
        /// </summary>
        private void AssociatedObject_GotFocus(object sender, RoutedEventArgs e)
        {
            if (AssociatedObject != null)
            {
                AssociatedObject.SelectAll();
            }
        } 

        #endregion
    }
}
